@@ -2,19 +2,21 @@
 
 # SPDX-License-Identifier: MIT AND AGPL-3.0-only
 
+# Up to date sources can be found at https://github.com/mmlb/ansi2txt
+
 import sys
 
 
 def getchar():
-    return sys.stdin.buffer.read(1)
+    return sys.stdin.read(1)
 
 
 def putchar(c):
-    return sys.stdout.buffer.write(c)
+    return sys.stdout.write(c)
 
 
 def main():
-    EOF = b""
+    EOF = ""
     ch = None
 
     while ch != EOF:
